@@ -252,17 +252,12 @@ static void
 gdl_dock_object_finalize (GObject *g_object)
 {
     GdlDockObject *object;
-    
-    g_return_if_fail (g_object != NULL && GDL_IS_DOCK_OBJECT (g_object));
 
     object = GDL_DOCK_OBJECT (g_object);
 
     g_free (object->name);
-    object->name = NULL;
     g_free (object->long_name);
-    object->long_name = NULL;
     g_free (object->stock_id);
-    object->stock_id = NULL;
 
     G_OBJECT_CLASS (gdl_dock_object_parent_class)->finalize (g_object);
 }
@@ -895,7 +890,7 @@ gdl_dock_object_register_init (void)
     g_relation_insert (dock_register, "placeholder", (gpointer) GDL_TYPE_DOCK_PLACEHOLDER);
 }
 
-G_CONST_RETURN gchar *
+const gchar *
 gdl_dock_object_nick_from_type (GType type)
 {
     GTuples *tuples;
